@@ -15,6 +15,9 @@ urlpatterns = patterns('',
     url(r'^(?P<snippet_id>\d+)/download/$',
         snippets.download_snippet,
         name='cab_snippet_download'),
+    url(r'^(?P<snippet_id>\d+)/raw/$',
+        snippets.raw_snippet,
+        name='cab_snippet_raw'),
     url(r'^(?P<snippet_id>\d+)/edit/$',
         snippets.edit_snippet,
         name='cab_snippet_edit'),
